@@ -273,6 +273,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                  max_retry_times=3, log_level=10, is_print_detail_exception=True,
                  msg_schedule_time_intercal=0.0, qps: float = 0, msg_expire_senconds=0,
                  is_using_distributed_frequency_control=False,
+                 is_send_consumer_hearbeat_to_redis=False,
                  logger_prefix='', create_logger_file=True, do_task_filtering=False,
                  task_filtering_expire_seconds=0, is_consuming_function_use_multi_params=True,
                  is_do_not_run_by_specify_time_effect=False,
@@ -348,6 +349,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             msg_schedule_time_intercal = 1.0 / qps  # 使用qps覆盖消息调度间隔，以qps为准，以后废弃msg_schedule_time_intercal这个参数。
         self._msg_schedule_time_intercal = msg_schedule_time_intercal if msg_schedule_time_intercal > 0.001 else 0.001
         self._is_using_distributed_frequency_control = is_using_distributed_frequency_control
+        self._is_send_consumer_hearbeat_to_redis = is_send_consumer_hearbeat_to_redis or is_using_distributed_frequency_control
         self._msg_expire_senconds = msg_expire_senconds
 
         if self._concurrent_mode not in (1, 2, 3):
@@ -402,6 +404,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
         self._publisher_of_same_queue = None
 
+        self.consumer_identification = f'{socket.gethostname()}_{time_util.DatetimeConverter().datetime_str.replace(":","-")}_{os.getpid()}_{id(self)}'
+
         self.custom_init()
 
     @property
@@ -448,13 +452,12 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
         return _keep_circulating
 
+    # noinspection PyAttributeOutsideInit
     def start_consuming_message(self):
         self.logger.warning(f'开始消费 {self._queue_name} 中的消息')
-        if self._is_using_distributed_frequency_control:
-            # noinspection PyAttributeOutsideInit
-            self._distributed_consumer_statistics = DistributedConsumerStatistics(self._queue_name,
-                                                                                  f'{socket.gethostname()} - {os.getpid()} - {id(self)}')
-
+        if self._is_send_consumer_hearbeat_to_redis:
+            self._distributed_consumer_statistics = DistributedConsumerStatistics(self._queue_name, self.consumer_identification)
+            self._distributed_consumer_statistics.run()
         self.keep_circulating(20, block=False)(self.check_heartbeat_and_message_count)()
         self._redis_filter.delete_expire_filter_task_cycle()
         if self._schedule_tasks_on_main_thread:
@@ -724,25 +727,31 @@ class DistributedConsumerStatistics(RedisMixin, LoggerMixinDefaultWithFileHandle
         self._queue_name = queue_name
         self._redis_key_name = f'hearbeat:{queue_name}'
         self.active_consumer_num = 1
-        self._send_heartbeat.__wrapped__(self)
-        self._send_heartbeat()
-        self._show_active_consumer_num()
         self._last_show_consumer_num_timestamp = 0
 
-    @decorators.keep_circulating(10, block=False)
-    def _send_heartbeat(self):
+    def run(self):
+        self.send_heartbeat()
+        decorators.keep_circulating(10, block=False)(self.send_heartbeat)()
+        decorators.keep_circulating(5, block=False)(self._show_active_consumer_num)()
+
+    def send_heartbeat(self):
         results = self.redis_db_frame.smembers(self._redis_key_name)
         with self.redis_db_frame.pipeline() as p:
             for result in results:
-                if time.time() - time_util.DatetimeConverter(result.decode().split('&&')[-1]).timestamp > 15 or \
+                if time.time() - float(result.decode().split('&&')[-1]) > 15 or \
                         self._consumer_identification == result.decode().split('&&')[0]:
                     p.srem(self._redis_key_name, result)
-            p.sadd(self._redis_key_name, f'{self._consumer_identification}&&{time_util.DatetimeConverter().datetime_str}')
+            p.sadd(self._redis_key_name, f'{self._consumer_identification}&&{time.time()}')
             p.execute()
 
-    @decorators.keep_circulating(5, block=False)
     def _show_active_consumer_num(self):
         self.active_consumer_num = self.redis_db_frame.scard(self._redis_key_name) or 1
         if time.time() - self._last_show_consumer_num_timestamp > 60:
             self.logger.info(f'分布式所有环境中使用 {self._queue_name} 队列的，一共有 {self.active_consumer_num} 个消费者')
             self._last_show_consumer_num_timestamp = time.time()
+
+    def get_queue_heartbeat_ids(self, without_time: bool):
+        if without_time:
+            return [idx.decode().split('&&')[0] for idx in self.redis_db_frame.smembers(self._redis_key_name)]
+        else:
+            return [idx.decode() for idx in self.redis_db_frame.smembers(self._redis_key_name)]
